@@ -18,45 +18,19 @@
 
 import time
 
-from .. import (
-    controldir,
-    debug,
-    errors,
-    osutils,
-    revision as _mod_revision,
-    trace,
-    ui,
-    )
-from ..bzr import (
-    chk_map,
-    chk_serializer,
-    index as _mod_index,
-    inventory,
-    pack,
-    versionedfile,
-    )
-from ..bzr.btree_index import (
-    BTreeGraphIndex,
-    BTreeBuilder,
-    )
-from ..bzr.groupcompress import (
-    _GCGraphIndex,
-    GroupCompressVersionedFiles,
-    )
-from .pack_repo import (
-    _DirectPackAccess,
-    Pack,
-    NewPack,
-    PackRepository,
-    PackCommitBuilder,
-    RepositoryPackCollection,
-    RepositoryFormatPack,
-    ResumedPack,
-    Packer,
-    )
-from ..bzr.vf_repository import (
-    StreamSource,
-    )
+from .. import controldir, debug, errors, osutils
+from .. import revision as _mod_revision
+from .. import trace, ui
+from ..bzr import chk_map, chk_serializer
+from ..bzr import index as _mod_index
+from ..bzr import inventory, pack, versionedfile
+from ..bzr.btree_index import BTreeBuilder, BTreeGraphIndex
+from ..bzr.groupcompress import GroupCompressVersionedFiles, _GCGraphIndex
+from ..bzr.vf_repository import StreamSource
+from .pack_repo import (NewPack, Pack, PackCommitBuilder, Packer,
+                        PackRepository, RepositoryFormatPack,
+                        RepositoryPackCollection, ResumedPack,
+                        _DirectPackAccess)
 from .static_tuple import StaticTuple
 
 
