@@ -24,11 +24,12 @@ __all__ = [
     'InMemoryGraphIndex',
     ]
 
+import re
 from bisect import bisect_right
 from io import BytesIO
-import re
 
 from ..lazy_import import lazy_import
+
 lazy_import(globals(), """
 from breezy import (
     bisect_multi,
@@ -36,11 +37,8 @@ from breezy import (
     trace,
     )
 """)
-from .. import (
-    debug,
-    errors,
-    transport as _mod_transport,
-    )
+from .. import debug, errors
+from .. import transport as _mod_transport
 from .static_tuple import StaticTuple
 
 _HEADER_READV = (0, 200)
@@ -166,7 +164,7 @@ class GraphIndexBuilder:
         if self._key_length != len(key):
             raise BadIndexKey(key)
         for element in key:
-            if not element or type(element) != bytes or _whitespace_re.search(element) is not None:
+            if not element or not isinstance(element, bytes) or _whitespace_re.search(element) is not None:
                 raise BadIndexKey(key)
 
     def _external_references(self):
