@@ -19,6 +19,7 @@ import sys
 from typing import Type
 
 from ..lazy_import import lazy_import
+
 lazy_import(globals(), """
 import contextlib
 import time
@@ -38,40 +39,18 @@ from breezy.bzr.index import (
     CombinedGraphIndex,
     )
 """)
-from .. import (
-    errors,
-    lockable_files,
-    lockdir,
-    transport as _mod_transport,
-    )
-from ..bzr import (
-    index,
-    btree_index,
-    )
-
-from ..decorators import (
-    only_raises,
-    )
+from .. import errors, lockable_files, lockdir
+from .. import transport as _mod_transport
+from ..bzr import btree_index, index
+from ..decorators import only_raises
 from ..lock import LogicalLockResult
-from ..repository import (
-    _LazyListJoin,
-    RepositoryWriteLockResult,
-    )
-from .repository import (
-    MetaDirRepository,
-    RepositoryFormatMetaDir,
-    )
+from ..repository import RepositoryWriteLockResult, _LazyListJoin
+from ..trace import mutter, note, warning
+from .repository import MetaDirRepository, RepositoryFormatMetaDir
 from .serializer import Serializer
-from .vf_repository import (
-    MetaDirVersionedFileRepository,
-    MetaDirVersionedFileRepositoryFormat,
-    VersionedFileCommitBuilder,
-    )
-from ..trace import (
-    mutter,
-    note,
-    warning,
-    )
+from .vf_repository import (MetaDirVersionedFileRepository,
+                            MetaDirVersionedFileRepositoryFormat,
+                            VersionedFileCommitBuilder)
 
 
 class RetryWithNewPacks(errors.BzrError):
