@@ -27,35 +27,17 @@ import zlib
 
 import fastbencode as bencode
 
-from ... import (
-    errors,
-    estimate_compressed_size,
-    osutils,
-    trace,
-    ui,
-    )
-from .. import (
-    inventory as _mod_inventory,
-    inventory_delta,
-    pack,
-    vf_search,
-    )
-from ..bzrdir import BzrDir
-from .request import (
-    FailedSmartServerResponse,
-    SmartServerRequest,
-    SuccessfulSmartServerResponse,
-    )
-from ...repository import (
-    _strip_NULL_ghosts,
-    network_format_registry,
-    )
+from ... import errors, estimate_compressed_size, osutils
 from ... import revision as _mod_revision
-from ..versionedfile import (
-    ChunkedContentFactory,
-    NetworkRecordStream,
-    record_to_fulltext_bytes,
-    )
+from ... import trace, ui
+from ...repository import _strip_NULL_ghosts, network_format_registry
+from .. import inventory as _mod_inventory
+from .. import inventory_delta, pack, vf_search
+from ..bzrdir import BzrDir
+from ..versionedfile import (ChunkedContentFactory, NetworkRecordStream,
+                             record_to_fulltext_bytes)
+from .request import (FailedSmartServerResponse, SmartServerRequest,
+                      SuccessfulSmartServerResponse)
 
 
 class SmartServerRepositoryRequest(SmartServerRequest):
