@@ -17,14 +17,10 @@
 
 import fastbencode as bencode
 
+from .. import errors, trace
+from .. import transport as _mod_transport
 from ..tag import Tags
 
-from .. import (
-    errors,
-    trace,
-    transport as _mod_transport,
-    )
-
 
 class BasicTags(Tags):
     """Tag storage in an unversioned branch control file.
