@@ -21,34 +21,16 @@ These tests are repeated for all pack-based repository formats.
 
 from stat import S_ISDIR
 
+from ... import controldir, errors, gpg, osutils, repository
+from ... import revision as _mod_revision
+from ... import tests, transport, ui
+from ...tests import TestCaseWithTransport, TestNotApplicable, test_server
+from ...transport import memory
+from .. import inventory
 from ..btree_index import BTreeGraphIndex
-from ..index import GraphIndex
-from ... import (
-    controldir,
-    errors,
-    gpg,
-    osutils,
-    repository,
-    revision as _mod_revision,
-    tests,
-    transport,
-    ui,
-    )
-from .. import (
-    inventory,
-    )
 from ..groupcompress_repo import RepositoryFormat2a
-from ..smart import (
-    client,
-    )
-from ...tests import (
-    TestCaseWithTransport,
-    TestNotApplicable,
-    )
-from ...transport import (
-    memory,
-    )
-from ...tests import test_server
+from ..index import GraphIndex
+from ..smart import client
 
 
 class TestPackRepository(TestCaseWithTransport):
