@@ -16,14 +16,8 @@
 
 """Tests for indices."""
 
-from ... import (
-    errors,
-    tests,
-    transport,
-    )
-from .. import (
-    index as _mod_index,
-    )
+from ... import errors, tests, transport
+from .. import index as _mod_index
 
 
 class ErrorTests(tests.TestCase):
