@@ -20,28 +20,17 @@
 
 import errno
 
-from . import (
-    bzrdir,
-    hashcache,
-    inventory,
-    transform as bzr_transform,
-    )
-
-from .. import (
-    errors,
-    osutils,
-    revision as _mod_revision,
-    trace,
-    transport as _mod_transport,
-    )
+from .. import errors, osutils
+from .. import revision as _mod_revision
+from .. import trace
+from .. import transport as _mod_transport
 from ..lockable_files import LockableFiles
 from ..lockdir import LockDir
 from ..mutabletree import MutableTree
 from ..transport.local import LocalTransport
-from .workingtree import (
-    InventoryWorkingTree,
-    WorkingTreeFormatMetaDir,
-    )
+from . import bzrdir, hashcache, inventory
+from . import transform as bzr_transform
+from .workingtree import InventoryWorkingTree, WorkingTreeFormatMetaDir
 
 
 class PreDirStateWorkingTree(InventoryWorkingTree):
