@@ -19,71 +19,42 @@
 
 
 import contextlib
-from io import BytesIO
 from collections import defaultdict
+from functools import partial
+from io import BytesIO
+from typing import Dict, Optional, Set, Tuple
 
-from dulwich.config import (
-    ConfigFile as GitConfigFile,
-    parse_submodules,
-    )
-
-from dulwich.objects import (
-    NotCommitError,
-    ZERO_SHA,
-    )
+from dulwich.config import ConfigFile as GitConfigFile
+from dulwich.config import parse_submodules
+from dulwich.objects import ZERO_SHA, NotCommitError
 from dulwich.repo import check_ref_format
 
-from .. import (
-    branch,
-    config,
-    controldir,
-    errors,
-    lock,
-    repository as _mod_repository,
-    revision,
-    trace,
-    transport,
-    urlutils,
-    )
+from .. import branch, config, controldir, errors, lock
+from .. import repository as _mod_repository
+from .. import revision, trace, transport, urlutils
 from ..foreign import ForeignBranch
-from ..revision import (
-    NULL_REVISION,
-    )
-from ..tag import (
-    Tags,
-    InterTags,
-    )
-from ..trace import (
-    is_quiet,
-    mutter,
-    warning,
-    )
+from ..revision import NULL_REVISION
+from ..tag import InterTags, TagConflict, Tags, TagSelector, TagUpdates
+from ..trace import is_quiet, mutter, warning
+from .errors import NoPushSupport
+from .mapping import decode_git_path, encode_git_path
+from .push import remote_divergence
+from .refs import (branch_name_to_ref, is_tag, ref_to_branch_name,
+                   ref_to_tag_name, tag_name_to_ref)
+from .unpeel_map import UnpeelMap
+from .urls import bzr_url_to_git_url, git_url_to_bzr_url
 
-from .errors import (
-    NoPushSupport,
-    )
-from .mapping import (
-    encode_git_path,
-    decode_git_path,
-    )
-from .push import (
-    remote_divergence,
-    )
-from .refs import (
-    branch_name_to_ref,
-    is_tag,
-    ref_to_branch_name,
-    ref_to_tag_name,
-    remote_refs_dict_to_tag_refs,
-    tag_name_to_ref,
-    )
-from .unpeel_map import (
-    UnpeelMap,
-    )
-from .urls import (
-    git_url_to_bzr_url,
-    bzr_url_to_git_url,
-    )
+
+def _update_tip(source, target, revid, overwrite=False):
+    if not overwrite:
+        last_rev = target.last_revision()
+        graph = target.repository.get_graph(source.repository)
+        if graph.is_ancestor(revid, last_rev):
+            # target is ahead of revid
+            return
+        target.generate_revision_history(revid, last_rev, other_branch=source)
+    else:
+        target.generate_revision_history(revid)
 
 
 def _calculate_revnos(branch):
@@ -126,9 +97,11 @@ class InterTagsFromGitToRemoteGit(InterTags):
             return False
         return True
 
-    def merge(self, overwrite=False, ignore_master=False, selector=None):
+    def merge(self, overwrite: bool = False, ignore_master: bool = False,
+              selector: Optional[TagSelector] = None) -> Tuple[
+                    TagUpdates, Set[TagConflict]]:
         if self.source.branch.repository.has_same_location(self.target.branch.repository):
-            return {}, []
+            return {}, set()
         updates = {}
         conflicts = []
         source_tag_refs = self.source.branch.get_tag_refs()
@@ -228,7 +201,7 @@ class InterTagsFromGitToLocalGit(InterTags):
 class InterTagsFromGitToNonGit(InterTags):
 
     @classmethod
-    def is_compatible(klass, source, target):
+    def is_compatible(klass, source: Tags, target: Tags):
         if not isinstance(source, GitTags):
             return False
         if isinstance(target, GitTags):
@@ -325,7 +298,7 @@ class LocalGitTagDict(GitTags):
     """Dictionary with tags in a local repository."""
 
     def __init__(self, branch):
-        super(LocalGitTagDict, self).__init__(branch)
+        super().__init__(branch)
         self.refs = self.repository.controldir._git.refs
 
     def _set_tag_dict(self, to_dict):
@@ -438,19 +411,21 @@ class GitBranch(ForeignBranch):
     def user_transport(self):
         return self._user_transport
 
-    def __init__(self, controldir, repository, ref, format):
+    def __init__(self, controldir, repository, ref: bytes, format):
         self.repository = repository
         self._format = format
         self.controldir = controldir
         self._lock_mode = None
         self._lock_count = 0
-        super(GitBranch, self).__init__(repository.get_mapping())
+        super().__init__(repository.get_mapping())
+        if not isinstance(ref, bytes):
+            raise TypeError("ref is invalid: %r" % ref)
         self.ref = ref
         self._head = None
         self._user_transport = controldir.user_transport.clone('.')
         self._control_transport = controldir.control_transport.clone('.')
         self._tag_refs = None
-        params = {}
+        params: Dict[str, str] = {}
         try:
             self.name = ref_to_branch_name(ref)
         except ValueError:
@@ -458,7 +433,7 @@ class GitBranch(ForeignBranch):
             if self.ref is not None:
                 params = {"ref": urlutils.escape(self.ref, safe='')}
         else:
-            if self.name != "":
+            if self.name:
                 params = {"branch": urlutils.escape(self.name, safe='')}
         for k, v in params.items():
             self._user_transport.set_segment_parameter(k, v)
@@ -474,6 +449,9 @@ class GitBranch(ForeignBranch):
         else:
             return controldir.format_registry.make_controldir("default")
 
+    def set_stacked_on_url(self, url):
+        raise branch.UnstackableBranchFormat(self._format, self.base)
+
     def get_child_submit_format(self):
         """Return the preferred format of submissions to this branch."""
         ret = self.get_config_stack().get("child_submit_format")
@@ -502,7 +480,7 @@ class GitBranch(ForeignBranch):
                     b"nick").decode("utf-8")
             except KeyError:
                 pass
-        return self.name or u"HEAD"
+        return self.name or "HEAD"
 
     def _set_nick(self, nick):
         cf = self.repository._git.get_config()
@@ -515,7 +493,7 @@ class GitBranch(ForeignBranch):
     nick = property(_get_nick, _set_nick)
 
     def __repr__(self):
-        return "<%s(%r, %r)>" % (self.__class__.__name__, self.repository.base,
+        return "<{}({!r}, {!r})>".format(self.__class__.__name__, self.repository.base,
                                  self.name)
 
     def set_last_revision(self, revid):
@@ -695,7 +673,7 @@ class GitBranch(ForeignBranch):
         raise errors.StoringUncommittedNotSupported(self)
 
     def _clear_cached_state(self):
-        super(GitBranch, self)._clear_cached_state()
+        super()._clear_cached_state()
         self._tag_refs = None
 
     def _iter_tag_refs(self, refs):
@@ -735,6 +713,7 @@ class GitBranch(ForeignBranch):
     def reconcile(self, thorough=True):
         """Make sure the data stored in this branch is consistent."""
         from ..reconcile import ReconcileResult
+
         # Nothing to do here
         return ReconcileResult()
 
@@ -743,7 +722,7 @@ class LocalGitBranch(GitBranch):
     """A local Git branch."""
 
     def __init__(self, controldir, repository, ref):
-        super(LocalGitBranch, self).__init__(controldir, repository, ref,
+        super().__init__(controldir, repository, ref,
                                              LocalGitBranchFormat())
 
     def create_checkout(self, to_location, revision_id=None, lightweight=False,
@@ -899,7 +878,7 @@ def _quick_lookup_revno(local_branch, remote_branch, revid):
 class GitBranchPullResult(branch.PullResult):
 
     def __init__(self):
-        super(GitBranchPullResult, self).__init__()
+        super().__init__()
         self.new_git_head = None
         self._old_revno = None
         self._new_revno = None
@@ -1027,13 +1006,9 @@ class InterFromGitBranch(branch.GenericInterBranch):
 
     def _update_revisions(self, stop_revision=None, overwrite=False, tag_selector=None):
         head, refs = self.fetch_objects(stop_revision, fetch_tags=None, tag_selector=tag_selector)
-        if overwrite:
-            prev_last_revid = None
-        else:
-            prev_last_revid = self.target.last_revision()
-        self.target.generate_revision_history(
-            self._last_revid, last_rev=prev_last_revid,
-            other_branch=self.source)
+        _update_tip(
+            self.source, self.target,
+            self._last_revid, overwrite)
         return head, refs
 
     def update_references(self, revid=None):
@@ -1047,13 +1022,13 @@ class InterFromGitBranch(branch.GenericInterBranch):
                     self.target.set_reference_info(
                         tree.path2id(decode_git_path(path)), url.decode('utf-8'),
                         decode_git_path(path))
-        except errors.NoSuchFile:
+        except transport.NoSuchFile:
             pass
 
     def _basic_pull(self, stop_revision, overwrite, run_hooks,
                     _override_hook_target, _hook_master, tag_selector=None):
         if overwrite is True:
-            overwrite = set(["history", "tags"])
+            overwrite = {"history", "tags"}
         elif not overwrite:
             overwrite = set()
         result = GitBranchPullResult()
@@ -1124,8 +1099,9 @@ class InterFromGitBranch(branch.GenericInterBranch):
                 master_branch = self.target.get_master_branch(possible_transports)
                 es.enter_context(master_branch.lock_write())
                 # pull from source into master.
-                master_branch.pull(self.source, overwrite, stop_revision,
-                                   run_hooks=False)
+                master_branch.pull(
+                    self.source, overwrite=overwrite,
+                    stop_revision=stop_revision, run_hooks=False)
             else:
                 master_branch = None
             return self._basic_pull(stop_revision, overwrite, run_hooks,
@@ -1135,7 +1111,7 @@ class InterFromGitBranch(branch.GenericInterBranch):
 
     def _basic_push(self, overwrite, stop_revision, tag_selector=None):
         if overwrite is True:
-            overwrite = set(["history", "tags"])
+            overwrite = {"history", "tags"}
         elif not overwrite:
             overwrite = set()
         result = branch.BranchPushResult()
@@ -1202,7 +1178,7 @@ class InterLocalGitRemoteGitBranch(InterGitBranch):
             result.new_revid = stop_revision
             for name, sha in (
                     self.source.repository._git.refs.as_dict(b"refs/tags").items()):
-                if tag_selector and not tag_selector(name):
+                if tag_selector and not tag_selector(name.decode('utf-8')):
                     continue
                 if sha not in self.source.repository._git:
                     trace.mutter('Ignoring missing SHA: %s', sha)
@@ -1238,6 +1214,9 @@ class InterGitLocalGitBranch(InterGitBranch):
                 isinstance(target, LocalGitBranch))
 
     def fetch(self, stop_revision=None, fetch_tags=None, limit=None, lossy=False):
+        if lossy:
+            raise errors.LossyPushToSameVCS(
+                source_branch=self.source, target_branch=self.target)
         interrepo = _mod_repository.InterRepository.get(
             self.source.repository, self.target.repository)
         if stop_revision is None:
@@ -1247,12 +1226,12 @@ class InterGitLocalGitBranch(InterGitBranch):
             fetch_tags = c.get('branch.fetch_tags')
         determine_wants = interrepo.get_determine_wants_revids(
             [stop_revision], include_tags=fetch_tags)
-        interrepo.fetch_objects(determine_wants, limit=limit, lossy=lossy)
+        interrepo.fetch_objects(determine_wants, limit=limit)
         return _mod_repository.FetchResult()
 
     def _basic_push(self, overwrite=False, stop_revision=None, tag_selector=None):
         if overwrite is True:
-            overwrite = set(["history", "tags"])
+            overwrite = {"history", "tags"}
         elif not overwrite:
             overwrite = set()
         result = GitBranchPushResult()
@@ -1260,10 +1239,10 @@ class InterGitLocalGitBranch(InterGitBranch):
         result.target_branch = self.target
         result.old_revid = self.target.last_revision()
         refs, stop_revision = self.update_refs(stop_revision)
-        self.target.generate_revision_history(
+        _update_tip(
+            self.source, self.target,
             stop_revision,
-            (result.old_revid if ("history" not in overwrite) else None),
-            other_branch=self.source)
+            "history" in overwrite)
         tags_ret = self.source.tags.merge_to(
             self.target.tags,
             overwrite=("tags" in overwrite),
@@ -1301,7 +1280,7 @@ class InterGitLocalGitBranch(InterGitBranch):
         if local:
             raise errors.LocalRequiresBoundBranch()
         if overwrite is True:
-            overwrite = set(["history", "tags"])
+            overwrite = {"history", "tags"}
         elif not overwrite:
             overwrite = set()
 
@@ -1311,10 +1290,10 @@ class InterGitLocalGitBranch(InterGitBranch):
         with self.target.lock_write(), self.source.lock_read():
             result.old_revid = self.target.last_revision()
             refs, stop_revision = self.update_refs(stop_revision)
-            self.target.generate_revision_history(
+            _update_tip(
+                self.source, self.target,
                 stop_revision,
-                (result.old_revid if ("history" not in overwrite) else None),
-                other_branch=self.source)
+                "history" in overwrite)
             tags_ret = self.source.tags.merge_to(
                 self.target.tags, overwrite=("tags" in overwrite),
                 selector=tag_selector)
@@ -1331,11 +1310,68 @@ class InterGitLocalGitBranch(InterGitBranch):
         return result
 
 
+def _update_pure_git_refs(result, new_refs, overwrite, tag_selector, old_refs):
+    mutter("updating refs. old refs: %r, new refs: %r",
+           old_refs, new_refs)
+    result.tag_updates = {}
+    result.tag_conflicts = []
+    ret = {}
+
+    def ref_equals(refs, name, git_sha, revid):
+        try:
+            value = refs[name]
+        except KeyError:
+            return False
+        if value[0] is not None and git_sha is not None:
+            return value[0] == git_sha
+        if value[1] is not None and revid is not None:
+            return value[1] == revid
+
+        # FIXME: If one side only has the git sha available and the other only
+        # has the bzr revid, then this will cause us to show a tag as updated
+        # that hasn't actually been updated.
+        return False
+    # FIXME: Check for diverged branches
+    for ref, (git_sha, revid) in new_refs.items():
+        if ref_equals(ret, ref, git_sha, revid):
+            # Already up to date
+            if git_sha is None:
+                git_sha = old_refs[ref][0]
+            if revid is None:
+                revid = old_refs[ref][1]
+            ret[ref] = new_refs[ref] = (git_sha, revid)
+        elif ref not in ret or overwrite:
+            try:
+                tag_name = ref_to_tag_name(ref)
+            except ValueError:
+                pass
+            else:
+                if tag_selector and not tag_selector(tag_name):
+                    continue
+                result.tag_updates[tag_name] = revid
+            ret[ref] = (git_sha, revid)
+        else:
+            # FIXME: Check diverged
+            diverged = False
+            if diverged:
+                try:
+                    name = ref_to_tag_name(ref)
+                except ValueError:
+                    pass
+                else:
+                    result.tag_conflicts.append(
+                        (name, revid, ret[name][1]))
+            else:
+                ret[ref] = (git_sha, revid)
+    return ret
+
+
+
 class InterToGitBranch(branch.GenericInterBranch):
     """InterBranch implementation that pulls into a Git branch."""
 
     def __init__(self, source, target):
-        super(InterToGitBranch, self).__init__(source, target)
+        super().__init__(source, target)
         self.interrepo = _mod_repository.InterRepository.get(source.repository,
                                                              target.repository)
 
@@ -1385,64 +1421,6 @@ class InterToGitBranch(branch.GenericInterBranch):
                     refs[ref] = (None, revid)
         return refs, main_ref, (stop_revno, stop_revision)
 
-    def _update_refs(self, result, old_refs, new_refs, overwrite, tag_selector):
-        mutter("updating refs. old refs: %r, new refs: %r",
-               old_refs, new_refs)
-        result.tag_updates = {}
-        result.tag_conflicts = []
-        ret = {}
-
-        def ref_equals(refs, ref, git_sha, revid):
-            try:
-                value = refs[ref]
-            except KeyError:
-                return False
-            if (value[0] is not None and
-                git_sha is not None and
-                    value[0] == git_sha):
-                return True
-            if (value[1] is not None and
-                revid is not None and
-                    value[1] == revid):
-                return True
-            # FIXME: If one side only has the git sha available and the other
-            # only has the bzr revid, then this will cause us to show a tag as
-            # updated that hasn't actually been updated.
-            return False
-        # FIXME: Check for diverged branches
-        for ref, (git_sha, revid) in new_refs.items():
-            if ref_equals(ret, ref, git_sha, revid):
-                # Already up to date
-                if git_sha is None:
-                    git_sha = old_refs[ref][0]
-                if revid is None:
-                    revid = old_refs[ref][1]
-                ret[ref] = new_refs[ref] = (git_sha, revid)
-            elif ref not in ret or overwrite:
-                try:
-                    tag_name = ref_to_tag_name(ref)
-                except ValueError:
-                    pass
-                else:
-                    if tag_selector and not tag_selector(tag_name):
-                        continue
-                    result.tag_updates[tag_name] = revid
-                ret[ref] = (git_sha, revid)
-            else:
-                # FIXME: Check diverged
-                diverged = False
-                if diverged:
-                    try:
-                        name = ref_to_tag_name(ref)
-                    except ValueError:
-                        pass
-                    else:
-                        result.tag_conflicts.append(
-                            (name, revid, ret[name][1]))
-                else:
-                    ret[ref] = (git_sha, revid)
-        return ret
-
     def fetch(self, stop_revision=None, fetch_tags=None, lossy=False,
               limit=None):
         if stop_revision is None:
@@ -1483,8 +1461,7 @@ class InterToGitBranch(branch.GenericInterBranch):
             new_refs, main_ref, stop_revinfo = self._get_new_refs(
                 stop_revision, stop_revno=_stop_revno)
 
-            def update_refs(old_refs):
-                return self._update_refs(result, old_refs, new_refs, overwrite, tag_selector)
+            update_refs = partial(_update_pure_git_refs, result, new_refs, overwrite, tag_selector)
             try:
                 result.revidmap, old_refs, new_refs = (
                     self.interrepo.fetch_refs(update_refs, lossy=False))
@@ -1515,8 +1492,7 @@ class InterToGitBranch(branch.GenericInterBranch):
             new_refs, main_ref, stop_revinfo = self._get_new_refs(
                 stop_revision, stop_revno=_stop_revno)
 
-            def update_refs(old_refs):
-                return self._update_refs(result, old_refs, new_refs, overwrite, tag_selector)
+            update_refs = partial(_update_pure_git_refs, result, new_refs, overwrite, tag_selector)
             try:
                 result.revidmap, old_refs, new_refs = (
                     self.interrepo.fetch_refs(
