@@ -21,110 +21,46 @@ import re
 
 from dulwich.refs import SymrefLoop
 
-from .. import (
-    config,
-    debug,
-    errors,
-    osutils,
-    trace,
-    ui,
-    urlutils,
-    )
+from .. import config, debug, errors, osutils, trace, ui, urlutils
 from ..controldir import BranchReferenceLoop
-from ..push import (
-    PushResult,
-    )
-from ..errors import (
-    AlreadyBranchError,
-    BzrError,
-    ConnectionReset,
-    DivergedBranches,
-    InProcessTransport,
-    InvalidRevisionId,
-    LockContention,
-    NoSuchRevision,
-    NoSuchTag,
-    NotBranchError,
-    NotLocalUrl,
-    PermissionDenied,
-    TransportError,
-    UnexpectedHttpStatus,
-    UninitializableFormat,
-    )
+from ..errors import (AlreadyBranchError, BzrError, ConnectionReset,
+                      DivergedBranches, InProcessTransport, InvalidRevisionId,
+                      LockContention, NoSuchRevision, NoSuchTag,
+                      NotBranchError, NotLocalUrl, PermissionDenied,
+                      TransportError, UnexpectedHttpStatus,
+                      UninitializableFormat)
+from ..push import PushResult
 from ..revision import NULL_REVISION
 from ..revisiontree import RevisionTree
-from ..transport import (
-    NoSuchFile,
-    Transport,
-    register_urlparse_netloc_protocol,
-    )
+from ..transport import (NoSuchFile, Transport,
+                         register_urlparse_netloc_protocol)
+from . import is_github_url, lazy_check_versions, user_agent_for_github
 
-from . import (
-    lazy_check_versions,
-    is_github_url,
-    user_agent_for_github,
-    )
 lazy_check_versions()
 
-from .branch import (
-    GitBranch,
-    GitBranchFormat,
-    GitBranchPushResult,
-    GitTags,
-    _quick_lookup_revno,
-    )
-from .dir import (
-    GitControlDirFormat,
-    GitDir,
-    )
-from .errors import (
-    GitSmartRemoteNotSupported,
-    )
-from .mapping import (
-    encode_git_path,
-    mapping_registry,
-    )
-from .object_store import (
-    get_object_store,
-    )
-from .push import (
-    remote_divergence,
-    )
-from .repository import (
-    GitRepository,
-    GitRepositoryFormat,
-    )
-from .refs import (
-    branch_name_to_ref,
-    is_peeled,
-    ref_to_tag_name,
-    tag_name_to_ref,
-    )
+import os
+import select
+import urllib.parse as urlparse
 
 import dulwich
 import dulwich.client
-from dulwich.errors import (
-    GitProtocolError,
-    HangupException,
-    )
-from dulwich.pack import (
-    Pack,
-    pack_objects_to_data,
-    load_pack_index,
-    PACK_SPOOL_FILE_MAX_SIZE,
-    )
+from dulwich.errors import GitProtocolError, HangupException
+from dulwich.pack import (PACK_SPOOL_FILE_MAX_SIZE, Pack, load_pack_index,
+                          pack_objects_to_data)
 from dulwich.protocol import ZERO_SHA
-from dulwich.refs import (
-    DictRefsContainer,
-    SYMREF,
-    )
-from dulwich.repo import (
-    NotGitRepository,
-    )
-import os
-import select
+from dulwich.refs import SYMREF, DictRefsContainer
+from dulwich.repo import NotGitRepository
 
-import urllib.parse as urlparse
+from .branch import (GitBranch, GitBranchFormat, GitBranchPushResult, GitTags,
+                     _quick_lookup_revno)
+from .dir import GitControlDirFormat, GitDir
+from .errors import GitSmartRemoteNotSupported
+from .mapping import encode_git_path, mapping_registry
+from .object_store import get_object_store
+from .push import remote_divergence
+from .refs import (branch_name_to_ref, is_peeled, ref_to_tag_name,
+                   tag_name_to_ref)
+from .repository import GitRepository, GitRepositoryFormat
 
 # urlparse only supports a limited number of schemes by default
 register_urlparse_netloc_protocol('git')
