@@ -18,44 +18,19 @@
 
 """Tests for interfacing with a Git Branch"""
 
-import dulwich
-from dulwich.objects import (
-    Commit,
-    Tag,
-    )
-from dulwich.repo import (
-    Repo as GitRepo,
-    )
-
 import os
 
-from ... import (
-    errors,
-    revision,
-    urlutils,
-    )
-from ...branch import (
-    Branch,
-    InterBranch,
-    UnstackableBranchFormat,
-    )
-from ...controldir import (
-    ControlDir,
-    )
-from ...repository import (
-    Repository,
-    )
+import dulwich
+from dulwich.objects import Commit, Tag
+from dulwich.repo import Repo as GitRepo
 
-from .. import (
-    branch,
-    tests,
-    )
-from ..dir import (
-    LocalGitControlDirFormat,
-    )
-from ..mapping import (
-    default_mapping,
-    )
+from ... import errors, revision, urlutils
+from ...branch import Branch, InterBranch, UnstackableBranchFormat
+from ...controldir import ControlDir
+from ...repository import Repository
+from .. import branch, tests
+from ..dir import LocalGitControlDirFormat
+from ..mapping import default_mapping
 
 
 class TestGitBranch(tests.TestCaseInTempDir):
