@@ -16,54 +16,23 @@
 
 """Tests from fetching from git into bzr."""
 
-from dulwich.objects import (
-    Blob,
-    Tag,
-    Tree,
-    S_IFGITLINK,
-    )
-from dulwich.repo import (
-    Repo as GitRepo,
-    )
 import os
 import stat
 import time
 
-from ... import (
-    osutils,
-    )
-from ...bzr import (
-    knit,
-    versionedfile,
-    )
-from ...branch import (
-    Branch,
-    )
-from ...controldir import (
-    ControlDir,
-    )
-from ...bzr.inventory import (
-    Inventory,
-    )
-from ...repository import (
-    Repository,
-    )
-from ...tests import (
-    TestCaseWithTransport,
-    )
+from dulwich.objects import S_IFGITLINK, Blob, Tag, Tree
+from dulwich.repo import Repo as GitRepo
 
-from ..fetch import (
-    import_git_blob,
-    import_git_tree,
-    import_git_submodule,
-    )
-from ..mapping import (
-    BzrGitMappingv1,
-    DEFAULT_FILE_MODE,
-    )
-from . import (
-    GitBranchBuilder,
-    )
+from ... import osutils
+from ...branch import Branch
+from ...bzr import knit, versionedfile
+from ...bzr.inventory import Inventory
+from ...controldir import ControlDir
+from ...repository import Repository
+from ...tests import TestCaseWithTransport
+from ..fetch import import_git_blob, import_git_submodule, import_git_tree
+from ..mapping import DEFAULT_FILE_MODE, BzrGitMappingv1
+from . import GitBranchBuilder
 
 
 class RepositoryFetchTests:
