@@ -18,13 +18,8 @@
 
 from io import BytesIO
 
-from ...tests import (
-    TestCaseWithTransport,
-    )
-
-from ..unpeel_map import (
-    UnpeelMap,
-    )
+from ...tests import TestCaseWithTransport
+from ..unpeel_map import UnpeelMap
 
 
 class TestUnpeelMap(TestCaseWithTransport):
