@@ -17,78 +17,49 @@
 
 """Git Trees."""
 
-from collections import deque
 import errno
+import os
+import posixpath
+import stat
+from collections import deque
 from functools import partial
 from io import BytesIO
-import os
+from typing import List, Set, Tuple, Union
 
-from dulwich.config import (
-    parse_submodules,
-    ConfigFile as GitConfigFile,
-    )
-from dulwich.diff_tree import tree_changes, RenameDetector
+from dulwich.config import ConfigFile as GitConfigFile
+from dulwich.config import parse_submodules
+from dulwich.diff_tree import RenameDetector, tree_changes
 from dulwich.errors import NotTreeError
-from dulwich.index import (
-    blob_from_path_and_stat,
-    cleanup_mode,
-    commit_tree,
-    index_entry_from_stat,
-    Index,
-    IndexEntry,
-    )
-from dulwich.object_store import (
-    OverlayObjectStore,
-    iter_tree_contents,
-    )
-from dulwich.objects import (
-    Blob,
-    Tree,
-    ZERO_SHA,
-    S_IFGITLINK,
-    S_ISGITLINK,
-    )
-import stat
-import posixpath
+from dulwich.index import (ConflictedIndexEntry, Index, IndexEntry,
+                           blob_from_path_and_stat, cleanup_mode, commit_tree,
+                           index_entry_from_stat)
+from dulwich.object_store import (BaseObjectStore, OverlayObjectStore,
+                                  iter_tree_contents)
+from dulwich.objects import (S_IFGITLINK, S_ISGITLINK, ZERO_SHA, Blob,
+                             ObjectID, Tree)
 
-from .. import (
-    controldir as _mod_controldir,
-    delta,
-    errors,
-    mutabletree,
-    osutils,
-    revisiontree,
-    trace,
-    transport as _mod_transport,
-    tree as _mod_tree,
-    urlutils,
-    workingtree,
-    )
-from ..revision import (
-    CURRENT_REVISION,
-    NULL_REVISION,
-    )
-from ..transport import get_transport
-from ..tree import MissingNestedTree
-
-from .mapping import (
-    encode_git_path,
-    decode_git_path,
-    mode_is_executable,
-    mode_kind,
-    default_mapping,
-    )
+from .. import controldir as _mod_controldir
+from .. import delta, errors, mutabletree, osutils, revisiontree, trace
+from .. import transport as _mod_transport
+from .. import tree as _mod_tree
+from .. import urlutils, workingtree
 from ..bzr.inventorytree import InventoryTreeChange
+from ..revision import CURRENT_REVISION, NULL_REVISION
+from ..transport import get_transport
+from ..tree import MissingNestedTree, TreeEntry
+from .mapping import (decode_git_path, default_mapping, encode_git_path,
+                      mode_is_executable, mode_kind)
 
 
 class GitTreeDirectory(_mod_tree.TreeDirectory):
 
-    __slots__ = ['file_id', 'name', 'parent_id']
+    __slots__ = ['file_id', 'name', 'parent_id', 'git_sha1']
 
-    def __init__(self, file_id, name, parent_id):
+    def __init__(self, file_id, name, parent_id, git_sha1=None):
         self.file_id = file_id
         self.name = name
         self.parent_id = parent_id
+        self.git_sha1 = git_sha1
 
     @property
     def kind(self):
@@ -158,14 +129,15 @@ class GitTreeFile(_mod_tree.TreeFile):
 
 class GitTreeSymlink(_mod_tree.TreeLink):
 
-    __slots__ = ['file_id', 'name', 'parent_id', 'symlink_target']
+    __slots__ = ['file_id', 'name', 'parent_id', 'symlink_target', 'git_sha1']
 
     def __init__(self, file_id, name, parent_id,
-                 symlink_target=None):
+                 symlink_target=None, git_sha1=None):
         self.file_id = file_id
         self.name = name
         self.parent_id = parent_id
         self.symlink_target = symlink_target
+        self.git_sha1 = git_sha1
 
     @property
     def kind(self):
@@ -199,13 +171,14 @@ class GitTreeSymlink(_mod_tree.TreeLink):
 
 class GitTreeSubmodule(_mod_tree.TreeReference):
 
-    __slots__ = ['file_id', 'name', 'parent_id', 'reference_revision']
+    __slots__ = ['file_id', 'name', 'parent_id', 'reference_revision', 'git_sha1']
 
-    def __init__(self, file_id, name, parent_id, reference_revision=None):
+    def __init__(self, file_id, name, parent_id, reference_revision=None, git_sha1=None):
         self.file_id = file_id
         self.name = name
         self.parent_id = parent_id
         self.reference_revision = reference_revision
+        self.git_sha1 = git_sha1
 
     @property
     def executable(self):
@@ -269,13 +242,6 @@ class GitTree(_mod_tree.Tree):
     def supports_symlinks(self):
         return True
 
-    def iter_git_objects(self):
-        """Iterate over all the objects in the tree.
-
-        :return :Yields tuples with (path, sha, mode)
-        """
-        raise NotImplementedError(self.iter_git_objects)
-
     def git_snapshot(self, want_unversioned=False):
         """Snapshot a tree, and return tree object.
 
@@ -550,7 +516,7 @@ class GitRevisionTree(revisiontree.RevisionTree, GitTree):
                         store, child_path, name, mode, hexsha, parent_id)
                 yield (decode_git_path(child_relpath), "V", ie.kind, ie)
 
-    def _get_file_ie(self, store, path, name, mode, hexsha, parent_id):
+    def _get_file_ie(self, store, path: str, name: str, mode: int, hexsha: bytes, parent_id):
         if not isinstance(path, bytes):
             raise TypeError(path)
         if not isinstance(name, bytes):
@@ -559,7 +525,7 @@ class GitRevisionTree(revisiontree.RevisionTree, GitTree):
         path = decode_git_path(path)
         name = decode_git_path(name)
         file_id = self.mapping.generate_file_id(path)
-        ie = entry_factory[kind](file_id, name, parent_id)
+        ie = entry_factory[kind](file_id, name, parent_id, git_sha1=hexsha)
         if kind == 'symlink':
             ie.symlink_target = decode_git_path(store[hexsha].data)
         elif kind == 'tree-reference':
@@ -571,12 +537,12 @@ class GitRevisionTree(revisiontree.RevisionTree, GitTree):
             ie.executable = mode_is_executable(mode)
         return ie
 
-    def _get_dir_ie(self, path, parent_id):
+    def _get_dir_ie(self, path, parent_id) -> GitTreeDirectory:
         path = decode_git_path(path)
         file_id = self.mapping.generate_file_id(path)
         return GitTreeDirectory(file_id, posixpath.basename(path), parent_id)
 
-    def iter_child_entries(self, path):
+    def iter_child_entries(self, path: str):
         (store, mode, tree_sha) = self._lookup_path(path)
 
         if mode is not None and not stat.S_ISDIR(mode):
@@ -746,6 +712,7 @@ class GitRevisionTree(revisiontree.RevisionTree, GitTree):
         with self.lock_read():
             # Now we have the parents of this content
             from breezy.annotate import Annotator
+
             from .annotate import AnnotateProvider
             annotator = Annotator(AnnotateProvider(
                 self._repository._file_change_scanner))
@@ -1157,6 +1124,8 @@ _mod_tree.InterTree.register_optimiser(InterGitTrees)
 
 class MutableGitIndexTree(mutabletree.MutableTree, GitTree):
 
+    store: BaseObjectStore
+
     def __init__(self):
         self._lock_mode = None
         self._lock_count = 0
@@ -1186,7 +1155,7 @@ class MutableGitIndexTree(mutabletree.MutableTree, GitTree):
         if self._lock_mode is None:
             raise errors.ObjectNotLocked(self)
         self._versioned_dirs = set()
-        for p, sha, mode in self.iter_git_objects():
+        for p, _entry in self._recurse_index_entries():
             self._ensure_versioned_dir(posixpath.dirname(p))
 
     def _ensure_versioned_dir(self, dirname):
@@ -1315,7 +1284,7 @@ class MutableGitIndexTree(mutabletree.MutableTree, GitTree):
         self.flush()
 
     def _index_add_entry(
-            self, path, kind, flags=0, reference_revision=None,
+            self, path, kind, reference_revision=None,
             symlink_target=None):
         if kind == "directory":
             # Git indexes don't contain directories
@@ -1376,23 +1345,24 @@ class MutableGitIndexTree(mutabletree.MutableTree, GitTree):
             trace.mutter('ignoring path with invalid newline in it: %r', path)
             return
         (index, index_path) = self._lookup_index(encoded_path)
-        index[index_path] = index_entry_from_stat(stat_val, hexsha, flags)
+        index[index_path] = index_entry_from_stat(stat_val, hexsha)
         self._index_dirty = True
         if self._versioned_dirs is not None:
             self._ensure_versioned_dir(index_path)
 
-    def iter_git_objects(self):
-        for p, entry in self._recurse_index_entries():
-            yield p, entry.sha, entry.mode
-
-    def _recurse_index_entries(self, index=None, basepath=b"",
-                               recurse_nested=False):
+    def _recurse_index_entries(self, index=None, basepath=b"", recurse_nested=False):
         # Iterate over all index entries
         with self.lock_read():
             if index is None:
                 index = self.index
             for path, value in index.items():
-                if S_ISGITLINK(value.mode) and recurse_nested:
+                if isinstance(value, ConflictedIndexEntry):
+                    if value.this is None:
+                        continue
+                    mode = value.this.mode
+                else:
+                    mode = value.mode
+                if S_ISGITLINK(mode) and recurse_nested:
                     subindex = self._get_submodule_index(path)
                     yield from self._recurse_index_entries(
                             index=subindex, basepath=path,
@@ -1446,34 +1416,45 @@ class MutableGitIndexTree(mutabletree.MutableTree, GitTree):
                 if entry.kind == 'tree-reference':
                     yield path
 
-    def _get_dir_ie(self, path, parent_id):
+    def _get_dir_ie(self, path: str, parent_id) -> GitTreeDirectory:
         file_id = self.path2id(path)
-        return GitTreeDirectory(file_id,
-                                posixpath.basename(path).strip("/"), parent_id)
+        return GitTreeDirectory(file_id, posixpath.basename(path).strip("/"), parent_id)
 
-    def _get_file_ie(self, name, path, value, parent_id):
+    def _get_file_ie(self, name: str, path: str, value: Union[IndexEntry, ConflictedIndexEntry], parent_id) -> Union[GitTreeSymlink, GitTreeDirectory, GitTreeFile, GitTreeSubmodule]:
         if not isinstance(name, str):
             raise TypeError(name)
         if not isinstance(path, str):
             raise TypeError(path)
-        if not isinstance(value, tuple) and not isinstance(value, IndexEntry):
+        if isinstance(value, IndexEntry):
+            mode = value.mode
+            sha = value.sha
+            size = value.size
+        elif isinstance(value, ConflictedIndexEntry):
+            if value.this is None:
+                raise _mod_transport.NoSuchFile(path)
+            mode = value.this.mode
+            sha = value.this.sha
+            size = value.this.size
+        else:
             raise TypeError(value)
         file_id = self.path2id(path)
         if not isinstance(file_id, bytes):
             raise TypeError(file_id)
-        kind = mode_kind(value.mode)
-        ie = entry_factory[kind](file_id, name, parent_id)
+        kind = mode_kind(mode)
+        ie = entry_factory[kind](file_id, name, parent_id, git_sha1=sha)
         if kind == 'symlink':
             ie.symlink_target = self.get_symlink_target(path)
         elif kind == 'tree-reference':
             ie.reference_revision = self.get_reference_revision(path)
+        elif kind == 'directory':
+            pass
         else:
-            ie.git_sha1 = value.sha
-            ie.text_size = value.size
-            ie.executable = bool(stat.S_ISREG(value.mode) and stat.S_IEXEC & value.mode)
+            ie.git_sha1 = sha
+            ie.text_size = size
+            ie.executable = bool(stat.S_ISREG(mode) and stat.S_IEXEC & mode)
         return ie
 
-    def _add_missing_parent_ids(self, path, dir_ids):
+    def _add_missing_parent_ids(self, path: str, dir_ids) -> List[Tuple[str, GitTreeDirectory]]:
         if path in dir_ids:
             return []
         parent = posixpath.dirname(path).strip("/")
@@ -1743,14 +1724,16 @@ class MutableGitIndexTree(mutabletree.MutableTree, GitTree):
                 return True
 
 
-def snapshot_workingtree(target, want_unversioned=False):
+def snapshot_workingtree(target: MutableGitIndexTree, want_unversioned: bool = False) -> Tuple[ObjectID, Set[bytes]]:
+    """Snapshot a working tree into a tree object."""
     extras = set()
     blobs = {}
     # Report dirified directories to commit_tree first, so that they can be
     # replaced with non-empty directories if they have contents.
     dirified = []
-    trust_executable = target._supports_executable()
+    trust_executable = target._supports_executable()  # type: ignore
     for path, index_entry in target._recurse_index_entries():
+        index_entry = getattr(index_entry, 'this', index_entry)
         try:
             live_entry = target._live_entry(path)
         except OSError as e:
@@ -1790,21 +1773,22 @@ def snapshot_workingtree(target, want_unversioned=False):
                         target.store.add_object(blob)
                 blobs[path] = (live_entry.sha, cleanup_mode(live_entry.mode))
     if want_unversioned:
-        for extra in target._iter_files_recursive(include_dirs=False):
+        for extra in target._iter_files_recursive(include_dirs=False):  # type: ignore
             extra, accessible = osutils.normalized_filename(extra)
             np = encode_git_path(extra)
             if np in blobs:
                 continue
-            st = target._lstat(extra)
+            st = target._lstat(extra)  # type: ignore
+            obj: Union[Tree, Blob]
             if stat.S_ISDIR(st.st_mode):
-                blob = Tree()
+                obj = Tree()
             elif stat.S_ISREG(st.st_mode) or stat.S_ISLNK(st.st_mode):
-                blob = blob_from_path_and_stat(
-                    os.fsencode(target.abspath(extra)), st)
+                obj = blob_from_path_and_stat(
+                    os.fsencode(target.abspath(extra)), st)  # type: ignore
             else:
                 continue
-            target.store.add_object(blob)
-            blobs[np] = (blob.id, cleanup_mode(st.st_mode))
+            target.store.add_object(obj)
+            blobs[np] = (obj.id, cleanup_mode(st.st_mode))
             extras.add(np)
     return commit_tree(
         target.store, dirified + [(p, s, m) for (p, (s, m)) in blobs.items()]), extras
