@@ -16,33 +16,16 @@
 
 """Tools for dealing with the Launchpad API."""
 
-from __future__ import absolute_import
-
 # Importing this module will be expensive, since it imports launchpadlib and
 # its dependencies. However, our plan is to only load this module when it is
 # needed by a command that uses it.
 
 
+import base64
 import re
-try:
-    from urllib.parse import (
-        urlparse,
-        urlunparse,
-        )
-except ImportError:  # python < 3
-    from urlparse import (
-        urlparse,
-        urlunparse,
-        )
+from urllib.parse import urlparse, urlunparse
 
-from ... import (
-    branch,
-    bedding,
-    errors,
-    osutils,
-    trace,
-    transport,
-    )
+from ... import bedding, branch, errors, osutils, trace, transport
 from ...i18n import gettext
 
 
@@ -52,18 +35,18 @@ class LaunchpadlibMissing(errors.DependencyNotPresent):
             "Please install the launchpadlib package.")
 
     def __init__(self, e):
-        super(LaunchpadlibMissing, self).__init__(
+        super().__init__(
             'launchpadlib', e)
 
 try:
     import launchpadlib
-except ImportError as e:
+except ModuleNotFoundError as e:
     raise LaunchpadlibMissing(e)
 
-from launchpadlib.launchpad import (
-    Launchpad,
-    )
-from launchpadlib import uris
+from launchpadlib.credentials import (AccessToken, Credentials,
+                                      CredentialStore,
+                                      RequestTokenAuthorizationEngine)
+from launchpadlib.launchpad import Launchpad
 
 # Declare the minimum version of launchpadlib that we need in order to work.
 MINIMUM_LAUNCHPADLIB_VERSION = (1, 6, 3)
@@ -89,16 +72,6 @@ def check_launchpadlib_compatibility():
             % (MINIMUM_LAUNCHPADLIB_VERSION, installed_version))
 
 
-def lookup_service_root(service_root):
-    try:
-        return uris.lookup_service_root(service_root)
-    except ValueError:
-        if service_root != 'qastaging':
-            raise
-        staging_root = uris.lookup_service_root('staging')
-        return staging_root.replace('staging', 'qastaging')
-
-
 class NoLaunchpadBranch(errors.BzrError):
     _fmt = 'No launchpad branch could be found for branch "%(url)s".'
 
@@ -106,6 +79,51 @@ class NoLaunchpadBranch(errors.BzrError):
         errors.BzrError.__init__(self, branch=branch, url=branch.base)
 
 
+def get_auth_engine(base_url):
+    return Launchpad.authorization_engine_factory(base_url, 'breezy')
+
+
+def get_credential_store():
+    return BreezyCredentialStore()
+    # return Launchpad.credential_store_factory()
+
+
+
+class BreezyCredentialStore(CredentialStore):
+    """Implementation of the launchpadlib CredentialStore API for Breezy.
+    """
+
+    def __init__(self, credential_save_failed=None):
+        super().__init__(credential_save_failed)
+        from breezy.config import AuthenticationConfig
+        self.auth_config = AuthenticationConfig()
+
+    def do_save(self, credentials, unique_key):
+        """Store newly-authorized credentials in the keyring."""
+        self.auth_config._set_option(
+            unique_key, 'consumer_key', credentials.consumer.key)
+        self.auth_config._set_option(
+            unique_key, 'consumer_secret', credentials.consumer.secret)
+        self.auth_config._set_option(
+            unique_key, 'access_token', credentials.access_token.key)
+        self.auth_config._set_option(
+            unique_key, 'access_secret', credentials.access_token.secret)
+
+    def do_load(self, unique_key):
+        """Retrieve credentials from the keyring."""
+        auth_def = self.auth_config._get_config().get(unique_key)
+        if auth_def and auth_def.get('access_secret'):
+            access_token = AccessToken(
+                auth_def.get('access_token'),
+                auth_def.get('access_secret'))
+            return Credentials(
+                consumer_name=auth_def.get('consumer_key'),
+                consumer_secret=auth_def.get('consumer_secret'),
+                access_token=access_token,
+                application_name='Breezy')
+        return None
+
+
 def connect_launchpad(base_url, timeout=None, proxy_info=None,
                       version=Launchpad.DEFAULT_VERSION):
     """Log in to the Launchpad API.
@@ -117,15 +135,33 @@ def connect_launchpad(base_url, timeout=None, proxy_info=None,
         proxy_info = httplib2.proxy_info_from_environment('https')
     try:
         cache_directory = get_cache_directory()
-    except EnvironmentError:
+    except OSError:
         cache_directory = None
-    return Launchpad.login_with(
-        'breezy', base_url, cache_directory, timeout=timeout,
-        proxy_info=proxy_info, version=version)
+    credential_store = get_credential_store()
+    authorization_engine = get_auth_engine(base_url)
+    from .account import get_lp_login
+    lp_user = get_lp_login()
+    if lp_user is None:
+        trace.mutter(
+            'Accessing launchpad API anonymously, since no username is set.')
+        return Launchpad.login_anonymously(
+            consumer_name='breezy',
+            service_root=base_url,
+            launchpadlib_dir=cache_directory,
+            timeout=timeout,
+            proxy_info=proxy_info,
+            version=version)
+    else:
+        return Launchpad.login_with(
+            application_name='breezy', service_root=base_url,
+            launchpadlib_dir=cache_directory, timeout=timeout,
+            credential_store=credential_store,
+            authorization_engine=authorization_engine,
+            proxy_info=proxy_info, version=version)
 
 
 
-class LaunchpadBranch(object):
+class LaunchpadBranch:
     """Provide bzr and lp API access to a Launchpad branch."""
 
     def __init__(self, lp_branch, bzr_url, bzr_branch=None, check_update=True):
@@ -170,67 +206,6 @@ class LaunchpadBranch(object):
                            '://bazaar.*.launchpad.net')
         return bool(regex.match(url))
 
-    @staticmethod
-    def candidate_urls(bzr_branch):
-        """Iterate through related URLs that might be Launchpad URLs.
-
-        :param bzr_branch: A Bazaar branch to find URLs from.
-        :return: a generator of URL strings.
-        """
-        url = bzr_branch.get_public_branch()
-        if url is not None:
-            yield url
-        url = bzr_branch.get_push_location()
-        if url is not None:
-            yield url
-        url = bzr_branch.get_parent()
-        if url is not None:
-            yield url
-        yield bzr_branch.base
-
-    @staticmethod
-    def tweak_url(url, launchpad):
-        """Adjust a URL to work with staging, if needed."""
-        if str(launchpad._root_uri) == uris.STAGING_SERVICE_ROOT:
-            return url.replace('bazaar.launchpad.net',
-                               'bazaar.staging.launchpad.net')
-        elif str(launchpad._root_uri) == lookup_service_root('qastaging'):
-            return url.replace('bazaar.launchpad.net',
-                               'bazaar.qastaging.launchpad.net')
-        return url
-
-    @classmethod
-    def from_bzr(cls, launchpad, bzr_branch, create_missing=True):
-        """Find a Launchpad branch from a bzr branch."""
-        check_update = True
-        for url in cls.candidate_urls(bzr_branch):
-            url = cls.tweak_url(url, launchpad)
-            if not cls.plausible_launchpad_url(url):
-                continue
-            lp_branch = launchpad.branches.getByUrl(url=url)
-            if lp_branch is not None:
-                break
-        else:
-            if not create_missing:
-                raise NoLaunchpadBranch(bzr_branch)
-            lp_branch = cls.create_now(launchpad, bzr_branch)
-            check_update = False
-        return cls(lp_branch, bzr_branch.base, bzr_branch, check_update)
-
-    @classmethod
-    def create_now(cls, launchpad, bzr_branch):
-        """Create a Bazaar branch on Launchpad for the supplied branch."""
-        url = cls.tweak_url(bzr_branch.get_push_location(), launchpad)
-        if not cls.plausible_launchpad_url(url):
-            raise errors.BzrError(gettext('%s is not registered on Launchpad') %
-                                  bzr_branch.base)
-        bzr_branch.create_clone_on_transport(transport.get_transport(url))
-        lp_branch = launchpad.branches.getByUrl(url=url)
-        if lp_branch is None:
-            raise errors.BzrError(gettext('%s is not registered on Launchpad') %
-                                  url)
-        return lp_branch
-
     def get_target(self):
         """Return the 'LaunchpadBranch' for the target of this one."""
         lp_branch = self.lp
@@ -282,12 +257,3 @@ class LaunchpadBranch(object):
         lca = graph.find_unique_lca(self.bzr.last_revision(),
                                     other.bzr.last_revision())
         return self.bzr.repository.revision_tree(lca)
-
-
-def canonical_url(object):
-    """Return the canonical URL for a branch."""
-    scheme, netloc, path, params, query, fragment = urlparse(
-        str(object.self_link))
-    path = '/'.join(path.split('/')[2:])
-    netloc = netloc.replace('api.', 'code.')
-    return urlunparse((scheme, netloc, path, params, query, fragment))
