@@ -17,17 +17,8 @@
 
 import operator
 
-from ... import (
-    branch,
-    commands,
-    config,
-    errors,
-    option,
-    trace,
-    tsort,
-    ui,
-    workingtree,
-    )
+from ... import (branch, commands, config, errors, option, trace, tsort, ui,
+                 workingtree)
 from ...revision import NULL_REVISION
 from .classify import classify_delta
 
