@@ -26,13 +26,9 @@ unique ID.
 
 import os
 
-from .... import (
-    errors,
-    transport as _mod_transport,
-    )
-from ....bzr import (
-    versionedfile,
-    )
+from .... import errors
+from .... import transport as _mod_transport
+from ....bzr import versionedfile
 from ....errors import BzrError, UnlistableStore
 from ....trace import mutter
 
