@@ -16,20 +16,19 @@
 
 """Test Store implementations."""
 
-from io import BytesIO
-import os
 import gzip
+import os
+from io import BytesIO
 
 from ... import errors as errors
+from ... import transactions, transport
+from ...bzr.weave import WeaveFile
 from ...errors import BzrError
+from ...tests import TestCase, TestCaseInTempDir, TestCaseWithTransport
+from ...transport.memory import MemoryTransport
 from .store import TransportStore
 from .store.text import TextStore
 from .store.versioned import VersionedFileStore
-from ...tests import TestCase, TestCaseInTempDir, TestCaseWithTransport
-from ... import transactions
-from ... import transport
-from ...transport.memory import MemoryTransport
-from ...bzr.weave import WeaveFile
 
 
 class TestStores:
