@@ -18,28 +18,18 @@
 
 from io import BytesIO
 
-from ... import (
-    conflicts as _mod_conflicts,
-    errors,
-    lock,
-    osutils,
-    revision as _mod_revision,
-    transport as _mod_transport,
-    )
-from ...bzr import (
-    conflicts as _mod_bzr_conflicts,
-    inventory,
-    transform as bzr_transform,
-    xml5,
-    )
+from ... import conflicts as _mod_conflicts
+from ... import errors, lock, osutils
+from ... import revision as _mod_revision
+from ... import transport as _mod_transport
+from ...bzr import conflicts as _mod_bzr_conflicts
+from ...bzr import inventory
+from ...bzr import transform as bzr_transform
+from ...bzr import xml5
+from ...bzr.workingtree_3 import PreDirStateWorkingTree
 from ...mutabletree import MutableTree
 from ...transport.local import LocalTransport
-from ...workingtree import (
-    WorkingTreeFormat,
-    )
-from ...bzr.workingtree_3 import (
-    PreDirStateWorkingTree,
-    )
+from ...workingtree import WorkingTreeFormat
 
 
 def get_conflicted_stem(path):
