@@ -16,18 +16,12 @@
 
 """UI helper for the push command."""
 
-from . import (
-    branch as _mod_branch,
-    controldir,
-    errors,
-    revision as _mod_revision,
-    transport,
-    )
-from .trace import (
-    note,
-    warning,
-    )
+from . import branch as _mod_branch
+from . import controldir, errors
+from . import revision as _mod_revision
+from . import transport
 from .i18n import gettext
+from .trace import note, warning
 
 
 class PushResult:
