@@ -17,13 +17,14 @@
 import errno
 import re
 
+import fastbencode as bencode
+
 from . import errors
 from .lazy_import import lazy_import
+
 lazy_import(globals(), """
 from breezy import (
-    bencode,
     merge,
-    merge3,
     transform,
 )
 from breezy.bzr import (
@@ -53,7 +54,7 @@ class InvalidShelfId(errors.BzrError):
         errors.BzrError.__init__(self, invalid_id=invalid_id)
 
 
-class ShelfCreator(object):
+class ShelfCreator:
     """Create a transform to shelve objects and its inverse."""
 
     def __init__(self, work_tree, target_tree, file_list=None):
@@ -274,7 +275,12 @@ class ShelfCreator(object):
         target_lines = self.target_tree.get_file_lines(target_path)
         work_path = self.work_tree.id2path(file_id)
         work_lines = self.work_tree.get_file_lines(work_path)
-        return merge3.Merge3(new_lines, target_lines, work_lines).merge_lines()
+        import patiencediff
+        from merge3 import Merge3
+        return Merge3(
+            new_lines, target_lines, work_lines,
+            sequence_matcher=patiencediff.PatienceSequenceMatcher,
+            ).merge_lines()
 
     def finalize(self):
         """Release all resources used by this ShelfCreator."""
@@ -316,7 +322,7 @@ class ShelfCreator(object):
         shelf_file.write(serializer.end())
 
 
-class Unshelver(object):
+class Unshelver:
     """Unshelve shelved changes."""
 
     def __init__(self, tree, base_tree, transform, message):
@@ -380,7 +386,7 @@ class Unshelver(object):
         self.transform.finalize()
 
 
-class ShelfManager(object):
+class ShelfManager:
     """Maintain a list of shelved changes."""
 
     def __init__(self, tree, transport):
@@ -429,7 +435,7 @@ class ShelfManager(object):
         filename = self.get_shelf_filename(shelf_id)
         try:
             return open(self.transport.local_abspath(filename), 'rb')
-        except IOError as e:
+        except OSError as e:
             if e.errno != errno.ENOENT:
                 raise
             raise NoSuchShelfId(shelf_id)
