@@ -19,17 +19,10 @@
 
 import os
 
-from breezy import (
-    osutils,
-    tests,
-    )
-from breezy.tests import (
-    features,
-    script,
-    )
+from breezy import osutils, tests
+from breezy.tests import features, script
 from breezy.tests.scenarios import load_tests_apply_scenarios
 
-
 load_tests = load_tests_apply_scenarios
 
 
