@@ -19,27 +19,16 @@
 
 import os
 
-from breezy import (
-    branch,
-    controldir,
-    errors,
-    revision as _mod_revision,
-    tests,
-    )
-from breezy.bzr import (
-    bzrdir,
-    )
+from breezy import branch, controldir, errors
+from breezy import revision as _mod_revision
+from breezy import tests
+from breezy.bzr import bzrdir
 from breezy.bzr.knitrepo import RepositoryFormatKnit1
-from breezy.tests import (
-    fixtures,
-    test_server,
-    )
-from breezy.tests.features import (
-    HardlinkFeature,
-    )
+from breezy.tests import fixtures, test_server
 from breezy.tests.blackbox import test_switch
-from breezy.tests.test_sftp_transport import TestCaseWithSFTPServer
+from breezy.tests.features import HardlinkFeature
 from breezy.tests.script import run_script
+from breezy.tests.test_sftp_transport import TestCaseWithSFTPServer
 from breezy.urlutils import local_path_to_url, strip_trailing_slash
 from breezy.workingtree import WorkingTree
 
@@ -496,8 +485,7 @@ class TestBranchStacked(tests.TestCaseWithTransport):
 
     def test_branch_stacked(self):
         # We have a mainline
-        trunk_tree = self.make_branch_and_tree('mainline',
-                                               format='1.9')
+        trunk_tree = self.make_branch_and_tree('mainline')
         original_revid = trunk_tree.commit('mainline')
         self.assertRevisionInRepository('mainline', original_revid)
         # and a branch from it which is stacked
