@@ -20,15 +20,7 @@ import os
 import re
 import unittest
 
-from breezy import (
-    bzr,
-    config,
-    controldir,
-    errors,
-    osutils,
-    repository,
-    tests,
-    )
+from breezy import bzr, config, controldir, errors, osutils, repository, tests
 from breezy.bzr.groupcompress_repo import RepositoryFormat2a
 
 
