@@ -14,21 +14,18 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from ...builtins import cmd_init_repository
-from .. import (
-    transport_util,
-    ui_testing,
-    )
+from ...builtins import cmd_init_shared_repository
+from .. import transport_util, ui_testing
 
 
 class TestInitRepository(transport_util.TestCaseWithConnectionHookedTransport):
 
     def setUp(self):
-        super(TestInitRepository, self).setUp()
+        super().setUp()
         self.start_logging_connections()
 
-    def test_init_repository(self):
-        cmd = cmd_init_repository()
+    def test_init_shared_repository(self):
+        cmd = cmd_init_shared_repository()
         # We don't care about the ouput but 'outf' should be defined
         cmd.outf = ui_testing.StringIOWithEncoding()
         cmd.run(self.get_url())
