@@ -16,13 +16,7 @@
 
 """Tests for the contract of commit on branches."""
 
-from breezy import (
-    branch,
-    delta,
-    errors,
-    revision,
-    transport,
-    )
+from breezy import branch, delta, errors, revision, transport
 from breezy.tests import per_branch
 
 
