@@ -18,10 +18,7 @@
 """Tests specific to Repository implementations that use foreign VCS'es."""
 
 
-from breezy.tests import (
-    TestCase,
-    TestCaseWithTransport,
-    )
+from breezy.tests import TestCase, TestCaseWithTransport
 
 
 class TestRepositoryFormat(TestCase):
