@@ -23,25 +23,14 @@ Specific tests for individual variations are in other places such as:
 """
 
 import breezy
-from breezy import (
-    revisiontree,
-    tests,
-    )
-from breezy.bzr import (
-    inventorytree,
-    )
-from breezy.tests import (
-    default_transport,
-    multiply_tests,
-    )
-from breezy.tests.per_tree import (
-    return_parameter,
-    revision_tree_from_workingtree,
-    TestCaseWithTree,
-    )
-from breezy.tree import InterTree
+from breezy import revisiontree, tests
+from breezy.bzr import inventorytree
 from breezy.bzr.workingtree_3 import WorkingTreeFormat3
 from breezy.bzr.workingtree_4 import WorkingTreeFormat4
+from breezy.tests import default_transport, multiply_tests
+from breezy.tests.per_tree import (TestCaseWithTree, return_parameter,
+                                   revision_tree_from_workingtree)
+from breezy.tree import InterTree
 
 
 def return_provided_trees(test_case, source, target):
