@@ -18,15 +18,10 @@
 
 import os
 
+from .. import errors
+from .. import merge as _mod_merge
 from ..bzr.conflicts import TextConflict
-from .. import (
-    errors,
-    merge as _mod_merge,
-    )
-from . import (
-    multiply_tests,
-    TestCaseWithTransport,
-    )
+from . import TestCaseWithTransport, multiply_tests
 from .test_merge_core import MergeBuilder
 
 
