@@ -16,20 +16,10 @@
 
 """Tests for fetch between repositories of the same type."""
 
-from breezy import (
-    controldir,
-    errors,
-    gpg,
-    repository,
-    )
-from breezy.bzr import (
-    remote,
-    )
+from breezy import controldir, errors, gpg, repository
+from breezy.bzr import remote
 from breezy.bzr.inventory import ROOT_ID
-from breezy.tests import (
-    TestNotApplicable,
-    TestSkipped,
-    )
+from breezy.tests import TestNotApplicable, TestSkipped
 from breezy.tests.per_repository import TestCaseWithRepository
 
 
