@@ -16,37 +16,19 @@
 
 """Tests for repository implementations - tests a repository format."""
 
-from io import BytesIO
 import re
+from io import BytesIO
 
-from ... import (
-    branch as _mod_branch,
-    commit,
-    controldir,
-    delta as _mod_delta,
-    errors,
-    gpg,
-    info,
-    repository,
-    revision as _mod_revision,
-    tests,
-    transport,
-    upgrade,
-    workingtree,
-    )
-from ...bzr import (
-    branch as _mod_bzrbranch,
-    inventory,
-    remote,
-    repository as bzrrepository,
-    )
-from ...bzr import (
-    knitpack_repo,
-    )
-from .. import (
-    per_repository,
-    test_server,
-    )
+from ... import branch as _mod_branch
+from ... import commit, controldir
+from ... import delta as _mod_delta
+from ... import errors, gpg, info, repository
+from ... import revision as _mod_revision
+from ... import tests, transport, upgrade, workingtree
+from ...bzr import branch as _mod_bzrbranch
+from ...bzr import inventory, knitpack_repo, remote
+from ...bzr import repository as bzrrepository
+from .. import per_repository, test_server
 from ..matchers import *
 
 
