@@ -14,12 +14,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from breezy.tests import (
-    per_tree,
-    )
-from breezy.tests.features import (
-    SymlinkFeature,
-    )
+from breezy.tests import per_tree
+from breezy.tests.features import SymlinkFeature
 
 
 class TestIsExecutable(per_tree.TestCaseWithTree):
@@ -32,7 +28,7 @@ class TestIsExecutable(per_tree.TestCaseWithTree):
         self.assertEqual(False, tree.is_executable('1top-dir'))
 
     def test_is_executable_symlink(self):
-        self.requireFeature(SymlinkFeature)
+        self.requireFeature(SymlinkFeature(self.test_dir))
         tree = self.get_tree_with_subdirs_and_all_content_types()
         tree.lock_read()
         self.addCleanup(tree.unlock)
