@@ -18,10 +18,7 @@
 
 import sys
 
-from breezy import (
-    branch,
-    errors,
-    )
+from breezy import branch, errors
 from breezy.tests import TestSkipped
 from breezy.tests.matchers import *
 from breezy.tests.per_workingtree import TestCaseWithWorkingTree
