@@ -15,10 +15,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
 
-from .. import (
-    cmdline,
-    tests,
-    )
+from .. import cmdline, tests
 from .features import backslashdir_feature
 
 
