@@ -17,17 +17,10 @@
 
 import os
 
-from .. import (
-    check,
-    osutils,
-    )
+from .. import check, osutils
 from ..commit import PointlessCommit
-from . import (
-    TestCaseWithTransport,
-    )
-from .features import (
-    SymlinkFeature,
-    )
+from . import TestCaseWithTransport
+from .features import SymlinkFeature
 from .matchers import RevisionHistoryMatches
 
 
