@@ -18,14 +18,9 @@
 
 import sys
 
-from .. import (
-    plugin as _mod_plugin,
-    symbol_versioning,
-    tests,
-    )
-from . import (
-    features,
-    )
+from .. import plugin as _mod_plugin
+from .. import symbol_versioning, tests
+from . import features
 
 
 class TestFeature(tests.TestCase):
