@@ -14,20 +14,14 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
+from io import BytesIO
+
 from .. import errors, filters
-from ..filters import (
-    ContentFilter,
-    ContentFilterContext,
-    filtered_input_file,
-    filtered_output_bytes,
-    _get_filter_stack_for,
-    _get_registered_names,
-    internal_size_sha_file_byname,
-    )
+from ..filters import (ContentFilter, ContentFilterContext,
+                       _get_filter_stack_for, _get_registered_names,
+                       filtered_input_file, filtered_output_bytes,
+                       internal_size_sha_file_byname)
 from ..osutils import sha_string
-from ..sixish import (
-    BytesIO,
-    )
 from . import TestCase, TestCaseInTempDir
 
 
