@@ -14,15 +14,12 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-from .. import (
-    errors,
-    graph as _mod_graph,
-    tests,
-    )
+from .. import errors
+from .. import graph as _mod_graph
+from .. import tests
 from ..revision import NULL_REVISION
 from . import TestCaseWithMemoryTransport
 
-
 # Ancestry 1:
 #
 #  NULL_REVISION
