@@ -16,20 +16,13 @@
 
 """Tests for breezy.location."""
 
-from .. import (
-    osutils,
-    tests,
-    urlutils,
-    )
+from .. import osutils, tests, urlutils
 from ..directory_service import directories
-from ..location import (
-    hooks as location_hooks,
-    location_to_url,
-    rcp_location_to_url,
-    )
+from ..location import hooks as location_hooks
+from ..location import location_to_url, rcp_location_to_url
 
 
-class SomeDirectory(object):
+class SomeDirectory:
 
     def look_up(self, name, url, purpose=None):
         return "http://bar"
@@ -40,11 +33,11 @@ class TestLocationToUrl(tests.TestCase):
     def get_base_location(self):
         path = osutils.abspath('/foo/bar')
         if path.startswith('/'):
-            url = 'file://%s' % (path,)
+            url = 'file://{}'.format(path)
         else:
             # On Windows, abspaths start with the drive letter, so we have to
             # add in the extra '/'
-            url = 'file:///%s' % (path,)
+            url = 'file:///{}'.format(path)
         return path, url
 
     def test_regular_url(self):
@@ -131,3 +124,5 @@ class RCPLocationTests(tests.TestCase):
     def test_invalid(self):
         self.assertRaises(ValueError, rcp_location_to_url, "http://srv/git/bar")
         self.assertRaises(ValueError, rcp_location_to_url, "git/bar")
+        # rcp host names cannot be shorter than two characters
+        self.assertRaises(ValueError, rcp_location_to_url, "c:/git/bar")
