@@ -16,18 +16,11 @@
 
 import re
 
-from .. import (
-    bzr,
-    commands,
-    controldir,
-    errors,
-    option,
-    registry,
-    )
+from .. import bzr, commands, controldir, errors, option, registry
 from ..builtins import cmd_commit
+from ..bzr import knitrepo
 from ..commands import parse_args
 from . import TestCase
-from ..bzr import knitrepo
 
 
 def parse(options, args):
