@@ -17,30 +17,15 @@
 
 import os.path
 
-from breezy.tests import TestCase, TestCaseWithTransport
-
 from breezy.iterablefile import IterableFile
-from breezy.patches import (
-    AppliedPatches,
-    MalformedLine,
-    MalformedHunkHeader,
-    MalformedPatchHeader,
-    BinaryPatch,
-    BinaryFiles,
-    Patch,
-    ContextLine,
-    InsertLine,
-    RemoveLine,
-    difference_index,
-    get_patch_names,
-    hunk_from_header,
-    iter_patched,
-    iter_patched_from_hunks,
-    parse_line,
-    parse_patch,
-    parse_patches,
-    NO_NL,
-    )
+from breezy.patches import (NO_NL, AppliedPatches, BinaryFiles, BinaryPatch,
+                            ContextLine, InsertLine, MalformedHunkHeader,
+                            MalformedLine, MalformedPatchHeader, Patch,
+                            RemoveLine, difference_index, get_patch_names,
+                            hunk_from_header, iter_patched,
+                            iter_patched_from_hunks, parse_line, parse_patch,
+                            parse_patches)
+from breezy.tests import TestCase, TestCaseWithTransport
 
 
 class PatchesTester(TestCase):
@@ -85,11 +70,22 @@ class PatchesTester(TestCase):
                          [b"--- orig/another.py\n", b"+++ mod/another.py\n"])
 
     def testValidPatchHeader(self):
+        """Parse a valid patch header"""
+        lines = (
+            b"--- orig/commands.py\t2020-09-09 23:39:35 +0000\n"
+            b"+++ mod/dommands.py\t2020-09-09 23:39:35 +0000\n").split(b'\n')
+        (orig, mod) = get_patch_names(lines.__iter__())
+        self.assertEqual(
+            orig, (b"orig/commands.py", b'2020-09-09 23:39:35 +0000'))
+        self.assertEqual(
+            mod, (b"mod/dommands.py", b'2020-09-09 23:39:35 +0000'))
+
+    def testValidPatchHeaderMissingTimestamps(self):
         """Parse a valid patch header"""
         lines = b"--- orig/commands.py\n+++ mod/dommands.py\n".split(b'\n')
         (orig, mod) = get_patch_names(lines.__iter__())
-        self.assertEqual(orig, b"orig/commands.py")
-        self.assertEqual(mod, b"mod/dommands.py")
+        self.assertEqual(orig, (b"orig/commands.py", None))
+        self.assertEqual(mod, (b"mod/dommands.py", None))
 
     def testInvalidPatchHeader(self):
         """Parse an invalid patch header"""
@@ -181,10 +177,10 @@ class PatchesTester(TestCase):
         patches = list(parse_patches(self.data_lines("binary.patch")))
         self.assertIs(BinaryPatch, patches[0].__class__)
         self.assertIs(Patch, patches[1].__class__)
-        self.assertContainsRe(patches[0].oldname, b'^bar\t')
-        self.assertContainsRe(patches[0].newname, b'^qux\t')
+        self.assertEqual(patches[0].oldname, b'bar')
+        self.assertEqual(patches[0].newname, b'qux')
         self.assertContainsRe(patches[0].as_bytes(),
-                              b'Binary files bar\t.* and qux\t.* differ\n')
+                              b'Binary files bar and qux differ\n')
 
     def test_parse_binary_after_normal(self):
         patches = list(parse_patches(
