@@ -20,22 +20,9 @@ import socketserver
 import sys
 import threading
 
-
-from breezy import (
-    cethread,
-    errors,
-    osutils,
-    transport,
-    urlutils,
-    )
-from breezy.transport import (
-    chroot,
-    pathfilter,
-    )
-from breezy.bzr.smart import (
-    medium,
-    server,
-    )
+from breezy import cethread, errors, osutils, transport, urlutils
+from breezy.bzr.smart import medium, server
+from breezy.transport import chroot, pathfilter
 
 
 def debug_threads():
