@@ -55,15 +55,16 @@ form.
 # that.
 
 import errno
-from io import StringIO
 import logging
 import os
 import sys
 import time
+from io import StringIO
 
 import breezy
 
 from .lazy_import import lazy_import
+
 lazy_import(globals(), """
 from breezy import (
     bedding,
@@ -72,10 +73,7 @@ from breezy import (
     ui,
     )
 """)
-from . import (
-    errors,
-    )
-
+from . import errors
 
 # global verbosity for breezy; controls the log level for stderr; 0=normal; <0
 # is quiet; >0 is verbose.
