@@ -17,12 +17,9 @@
 """Topological sorting routines."""
 
 
-from . import (
-    errors,
-    graph as _mod_graph,
-    revision as _mod_revision,
-    )
-
+from . import errors
+from . import graph as _mod_graph
+from . import revision as _mod_revision
 
 __all__ = ["topo_sort", "TopoSorter", "merge_sort", "MergeSorter"]
 
