@@ -4,7 +4,8 @@
 #
 # This file is execfile()d with the current directory set to its containing dir.
 
-import sys, os
+import os
+import sys
 
 # If extensions (or modules to document with autodoc) are in another directory,
 # add these directories to sys.path here. If the directory is relative to the
@@ -14,7 +15,6 @@ sys.path = [os.path.abspath('../..'), os.path.abspath('api')] + sys.path
 # Most of the configuration for Breezy docs is defined here ...
 from breezy.doc_generate.conf import *
 
-
 ## Configuration specific to this site ##
 
 # The locale code for this documentation set
